==> dbio-1.0.0.tar.gz: lib/src/UserDetails.dart <==
class UserDetails {
  bool success;
  Payload payload;

  UserDetails({this.success, this.payload});

  UserDetails.fromJson(Map<String, dynamic> json) {
    success = json['success'];
    payload = json['payload'] != null ? new Payload.fromJson(json["payload"]) : null;
    
  }
}

class Payload{
  Settings settings;
  Discord discord;

  Payload({this.settings,this.discord});

  Payload.fromJson(Map<String, dynamic> json) {
    settings = json['settings'] != null ? new Settings.fromJson(json['settings']) : null;
    discord = json['discord'] != null ? new Discord.fromJson(json['discord']) : null;
  }
}

class Settings {
  String name;
  int id;
  String userId;
  int premiumStatus;
  int flags;
  int verified;
  int upvotes;
  String createdAt;
  String status;
  String description;
  String location;
  int gender;
  String birthday;
  String email;
  String occupation;
  String  banner;

  Settings(
      {this.name,
      this.id,
      this.userId,
      this.premiumStatus,
      this.flags,
      this.verified,
      this.upvotes,
      this.createdAt,
      this.status,
      this.description,
      this.location,
      this.gender,
      this.birthday,
      this.email,
      this.occupation,
      this.banner});

  Settings.fromJson(Map<String, dynamic> json) {
    name = json['name'];
    id = json['id'];
    userId = json['user_id'];
    premiumStatus = json['premium_status'];
    flags = json['flags'];
    verified = json['verified'];
    upvotes = json['upvotes'];
    createdAt = json['created_at'];
    status = json['status'];
    description = json['description'];
    location = json['location'];
    gender = json['gender'];
    birthday = json['birthday'];
    email = json['email'];
    occupation = json['occupation'];
    banner = json['banner'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['name'] = this.name;
    data['id'] = this.id;
    data['user_id'] = this.userId;
    data['premium_status'] = this.premiumStatus;
    data['flags'] = this.flags;
    data['verified'] = this.verified;
    data['upvotes'] = this.upvotes;
    data['created_at'] = this.createdAt;
    data['status'] = this.status;
    data['description'] = this.description;
    data['location'] = this.location;
    data['gender'] = this.gender;
    data['birthday'] = this.birthday;
    data['email'] = this.email;
    data['occupation'] = this.occupation;
    data['banner'] = this.banner;
    return data;
  }
}

class Discord {
  String id;
  String username;
  String avatar;
  String discriminator;

  Discord({this.id, this.username, this.avatar, this.discriminator});

  Discord.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    username = json['username'];
    avatar = json['avatar'];
    discriminator = json['discriminator'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['id'] = this.id;
    data['username'] = this.username;
    data['avatar'] = this.avatar;
    data['discriminator'] = this.discriminator;
    return data;
  }
}

==> dbio-1.0.1.tar.gz: lib/src/UserDetails.dart <==
class UserDetails {
  bool success;
  Payload payload;

  UserDetails({this.success, this.payload});

  UserDetails.fromJson(Map<String, dynamic> json) {
    success = json['success'];
    payload = json['payload'] != null ? Payload.fromJson(json["payload"]) : null;
    
  }
}

class Payload{
  Settings settings;
  Discord discord;

  Payload({this.settings,this.discord});

  Payload.fromJson(Map<String, dynamic> json) {
    settings = json['settings'] != null ? Settings.fromJson(json['settings']) : null;
    discord = json['discord'] != null ? Discord.fromJson(json['discord']) : null;
  }
}

class Settings {
  String name;
  int id;
  String userId;
  int premiumStatus;
  int flags;
  int verified;
  int upvotes;
  String createdAt;
  String status;
  String description;
  String location;
  int gender;
  String birthday;
  String email;
  String occupation;
  String  banner;

  Settings(
      {this.name,
      this.id,
      this.userId,
      this.premiumStatus,
      this.flags,
      this.verified,
      this.upvotes,
      this.createdAt,
      this.status,
      this.description,
      this.location,
      this.gender,
      this.birthday,
      this.email,
      this.occupation,
      this.banner});

  Settings.fromJson(Map<String, dynamic> json) {
    name = json['name'];
    id = json['id'];
    userId = json['user_id'];
    premiumStatus = json['premium_status'];
    flags = json['flags'];
    verified = json['verified'];
    upvotes = json['upvotes'];
    createdAt = json['created_at'];
    status = json['status'];
    description = json['description'];
    location = json['location'];
    gender = json['gender'];
    birthday = json['birthday'];
    email = json['email'];
    occupation = json['occupation'];
    banner = json['banner'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['name'] = this.name;
    data['id'] = this.id;
    data['user_id'] = this.userId;
    data['premium_status'] = this.premiumStatus;
    data['flags'] = this.flags;
    data['verified'] = this.verified;
    data['upvotes'] = this.upvotes;
    data['created_at'] = this.createdAt;
    data['status'] = this.status;
    data['description'] = this.description;
    data['location'] = this.location;
    data['gender'] = this.gender;
    data['birthday'] = this.birthday;
    data['email'] = this.email;
    data['occupation'] = this.occupation;
    data['banner'] = this.banner;
    return data;
  }
}

class Discord {
  String id;
  String username;
  String avatar;
  String discriminator;

  Discord({this.id, this.username, this.avatar, this.discriminator});

  Discord.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    username = json['username'];
    avatar = json['avatar'];
    discriminator = json['discriminator'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['id'] = this.id;
    data['username'] = this.username;
    data['avatar'] = this.avatar;
    data['discriminator'] = this.discriminator;
    return data;
  }
}
